@@ -5,7 +5,7 @@ void ac_error(
     const char* msg
 ){
 
-  Rf_error(msg);
+  Rf_error("%s", msg);
 
 }
 
@@ -13,6 +13,6 @@ void ac_error(
     const std::string msg
 ){
 
-  Rf_error(msg.c_str());
+  Rf_error("%s", msg.c_str());
 
 }
